summaryrefslogtreecommitdiffhomepage
path: root/gui/src/renderer/components
diff options
context:
space:
mode:
authorMarkus Pettersson <markus.pettersson@mullvad.net>2024-10-18 12:50:35 +0200
committerMarkus Pettersson <markus.pettersson@mullvad.net>2024-10-23 14:59:46 +0200
commitb83716e758ec7cd0153d2b30749da57e80b24132 (patch)
tree7b57c50ae0d4969688af9ef09ce1f21f3d9387a6 /gui/src/renderer/components
parent2ba727134060eb434c8335c0ae0970ba3e4f21cb (diff)
downloadmullvadvpn-b83716e758ec7cd0153d2b30749da57e80b24132.tar.xz
mullvadvpn-b83716e758ec7cd0153d2b30749da57e80b24132.zip
Add 'Encrypted DNS proxy' built-in access method to GUI
Diffstat (limited to 'gui/src/renderer/components')
-rw-r--r--gui/src/renderer/components/ApiAccessMethods.tsx20
1 files changed, 19 insertions, 1 deletions
diff --git a/gui/src/renderer/components/ApiAccessMethods.tsx b/gui/src/renderer/components/ApiAccessMethods.tsx
index 57668df787..8b88e97edc 100644
--- a/gui/src/renderer/components/ApiAccessMethods.tsx
+++ b/gui/src/renderer/components/ApiAccessMethods.tsx
@@ -133,6 +133,10 @@ export default function ApiAccessMethods() {
method={methods.mullvadBridges}
inUse={methods.mullvadBridges.id === currentMethod?.id}
/>
+ <ApiAccessMethod
+ method={methods.encryptedDnsProxy}
+ inUse={methods.encryptedDnsProxy.id === currentMethod?.id}
+ />
{methods.custom.map((method) => (
<ApiAccessMethod
key={method.id}
@@ -211,7 +215,7 @@ function ApiAccessMethod(props: ApiAccessMethodProps) {
},
];
// Edit and Delete shouldn't be available for direct and bridges.
if (props.custom) {
items.push(
{ type: 'separator' as const },
@@ -290,6 +294,20 @@ function ApiAccessMethod(props: ApiAccessMethodProps) {
]}
/>
)}
+ {props.method.type === 'encrypted-dns-proxy' && (
+ <StyledMethodInfoButton
+ message={[
+ messages.pgettext(
+ 'api-access-methods-view',
+ 'With the “Encrypted DNS proxy” method, the app will communicate with our Mullvad API through a proxy address. It does this by retrieving an address from a DNS over HTTPS (DoH) server and then using that to reach our API servers.',
+ ),
+ messages.pgettext(
+ 'api-access-methods-view',
+ 'If you are not connected to our VPN, then the Encrypted DNS proxy will use your own non-VPN IP when connecting. The DoH servers are hosted by one of the following providers: Quad 9, CloudFlare, or Google.',
+ ),
+ ]}
+ />
+ )}
<ContextMenuContainer>
<ContextMenuTrigger>
<StyledContextMenuButton
@@ -211,7 +215,7 @@ function ApiAccessMethod(props: ApiAccessMethodProps) {
},
];
- // Edit and Delete shouldn't be available for direct and bridges.
+ // Edit and Delete shouldn't be available for direct, bridges or encrypted DNS proxy.
if (props.custom) {
items.push(